@@ -5,10 +5,9 @@
  *
  * Author:  jacob berkman  <jacob@bug-buddy.org>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of version 2 of the GNU General Public
+ * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -23,8 +22,13 @@
 #ifndef __BUGZILLA_H__
 #define __BUGZILLA_H__
 
-#include <libgnomevfs/gnome-vfs-types.h>
-#include <parser.h>
+#include <libgnomevfs/gnome-vfs-uri.h>
+#include <libxml/parser.h>
+#include <gdk-pixbuf/gdk-pixbuf.h>
+#include <gtk/gtktreemodel.h>
+
+#define DOWNLOAD_FINISHED_OK_RESPONSE 1001
+#define DOWNLOAD_FINISHED_ZERO_RESPONSE 1002
 
 typedef struct _BugzillaBTS BugzillaBTS;
 
@@ -38,6 +42,7 @@ typedef enum {
 typedef struct {
 	char *system_path;
 	char *cache_path;
+	char *tmp_path;
 
 	GnomeVFSURI *source_uri;
 	GnomeVFSURI *dest_uri;
@@ -56,26 +61,38 @@ struct _BugzillaBTS {
 
 	BugzillaXMLFile *products_xml;
 	BugzillaXMLFile *config_xml;
+	BugzillaXMLFile *mostfreq_xml;
+
+	char products_xml_md5[33];
+	char config_xml_md5[33];
+	char mostfreq_xml_md5[33];
+	gboolean md5s_downloaded;
 
 	BugzillaSubmitType submit_type;
 	char *icon;
 
-	GdkPixmap *pixmap;
-	GdkBitmap *mask;
+	GdkPixbuf *pixbuf;
+
+	char *severity_node;
+	char *severity_item;
+	char *severity_header;
 	
 	/* products.xml */
-	GSList    *products;
+	GHashTable *products;
 
 	/* config.xml */
 	GSList    *severities;
 	GSList    *opsys;
+
+	/* mostfreq.xml */
+	GSList *bugs;
 };
 
 typedef struct {
 	BugzillaBTS *bts;
 	char        *name;
 	char        *description;
-	GSList      *components;
+	GHashTable  *components;
 } BugzillaProduct;
 
 typedef struct {
@@ -84,12 +101,73 @@ typedef struct {
 	char            *description;
 } BugzillaComponent;
 
+typedef struct {
+	char *id;
+	char *product;
+	char *component;
+	char *desc;
+	char *url;
+	/* gboolean shown : 1; */
+} BugzillaBug;
+
+typedef struct {
+	char *name;
+	char *comment;
+	GdkPixbuf *pixbuf;
+	char *bugzilla;
+	char *product;
+	char *component;
+	char *version;
+	char *email;
+	GtkTreeIter iter;
+} BugzillaApplication;
+
+enum {
+	PRODUCT_ICON,
+	PRODUCT_NAME,
+	PRODUCT_DESC,
+	PRODUCT_DATA,
+
+	PRODUCT_COLS
+};
+
+enum {
+	COMPONENT_NAME,
+	COMPONENT_DESC,
+	COMPONENT_DATA,
+
+	COMPONENT_COLS
+};
+
+enum {
+	MOSTFREQ_PRODUCT,
+	MOSTFREQ_COMPONENT,
+	MOSTFREQ_ID,
+	MOSTFREQ_URL,
+	MOSTFREQ_DESC,
+	MOSTFREQ_SHOWN,
+
+	MOSTFREQ_COLS,
+};
+
+void load_applications (void);
 void load_bugzillas (void);
 void load_bugzilla_xml (void);
 
-void bugzilla_bts_add_products_to_clist (BugzillaBTS *bts);
+void products_list_load (void);
 void bugzilla_product_add_components_to_clist (BugzillaProduct *product);
 
-char *generate_email_text (void);
+gboolean bugzilla_add_mostfreq (BugzillaBTS *bts);
+
+char *generate_email_text (gboolean include_headers);
+
+gboolean start_bugzilla_download (void);
+
+typedef enum {
+	END_BUGZILLA_NOOP     = 0,
+	END_BUGZILLA_CANCEL   = 1 << 0,
+	END_BUGZILLA_HIDE_BOX = 1 << 1
+} EndBugzillaFlags;
+void end_bugzilla_download (int count);
 
 #endif /* __BUGZILLA_H__ */
