@@ -65,6 +65,28 @@ static char *state_title[] = {
 
 #define d(x)
 
+static void
+mail_lock_text (void)
+{
+	GtkTextView *view;
+	GtkTextBuffer *buffer;
+	GtkTextIter start, end;
+	GtkTextTagTable *tag_table;
+	GtkTextTag *tag;
+
+	view = GTK_TEXT_VIEW (GET_WIDGET ("email-text"));
+	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
+
+	gtk_text_buffer_get_start_iter (buffer, &start);
+	gtk_text_iter_forward_search (&start, "Description:",
+				      GTK_TEXT_SEARCH_TEXT_ONLY,
+				      NULL, &end, NULL);		
+				  
+	tag_table = gtk_text_buffer_get_tag_table (buffer);
+	tag = gtk_text_tag_table_lookup (tag_table, "lock_tag");
+	gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
+}
+
 void
 druid_set_sensitive (gboolean prev, gboolean next, gboolean cancel)
 {
@@ -202,6 +224,7 @@ druid_set_state (BuddyState state)
 		buddy_set_text ("email-text", s);
 		g_free (s);
 		on_email_group_toggled (NULL, NULL);
+		mail_lock_text ();
 		break;
 	case STATE_FINISHED:
 		/* print a summary yo */
@@ -761,7 +784,7 @@ on_druid_next_clicked (GtkWidget *w, gpointer data)
 		if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (GET_WIDGET ("type-debug-button")))) {
 			druid_data.bug_type = BUG_DEBUG;
 			newstate = STATE_GDB;
-			buddy_set_text ("gdb_label", _("Please, select the select the core file or running application to debug."));
+			buddy_set_text ("gdb_label", _("Please, select the core file or running application to debug."));
 			break;
 		}
 		newstate = STATE_PRODUCT;
@@ -813,7 +836,7 @@ on_druid_next_clicked (GtkWidget *w, gpointer data)
 	case STATE_PRODUCT:
 	{
 		BugzillaProduct *product = NULL;
-		BugzillaApplication *application;
+		BugzillaApplication *application = NULL;
 		/* check that the package is ok */
 		if (GTK_TOGGLE_BUTTON (GET_WIDGET ("no-product-toggle"))->active) {
 			static gboolean dialog_shown = FALSE;
@@ -906,10 +929,15 @@ on_druid_next_clicked (GtkWidget *w, gpointer data)
 			buddy_set_text ("email-to-entry", druid_data.product->bts->email);
 		}
 		
-		if (application->component) {
+		if (application && application->component) {
 			select_component_row (application->component);
 		}
 
+		if (application && application->version) {
+			gtk_entry_set_text (GTK_ENTRY (GET_WIDGET ("the-version-entry")),
+					    application->version);
+		}
+
 		if (druid_data.bug_type == BUG_REQUEST  &&
 		    g_slist_find (druid_data.product->bts->severities, "enhancement")!=NULL) {
 			druid_data.severity = "enhancement";
